@@ -95,6 +95,10 @@ sub SplitterWindow {
    my $banner = Wx::BannerWindow->new($splitterWindow);
    $banner->SetBitmap( $logo );
    $banner->Show(1);
+   my $don = Wx::Bitmap->new("donate.png",
+                         wxBITMAP_TYPE_PNG );
+   my $dn=Wx::BitmapButton->new($banner,-1,$don,[12.7,12.7]);
+   $dn->Enable(1);
 	
    my $rightWindows = Wx::SplitterWindow->new($splitterWindow, -1);
    $rightWindows->Show(1);
@@ -398,17 +402,28 @@ sub SplitterWindow {
    $new_server_chkbox->SetValue(1) unless ($ip_txt || $saved_txt);
    EVT_CHECKBOX( $rightbottom, $new_server_chkbox,
                            \&main::OnClick_chkbox3 );
-   my $eng = Wx::Bitmap->new("engineroom.jpg",
-                         wxBITMAP_TYPE_JPEG );
-   my $eht=86;
+   #my $eng = Wx::Bitmap->new("engineroom.jpg",
+   #                      wxBITMAP_TYPE_JPEG );
+   my $clb = Wx::Bitmap->new("cb.png",
+                         wxBITMAP_TYPE_PNG );
+   my $cbt=80;
    if ($pem_file && $ip_txt) {
-      $eht=16;
+      $cbt=16;
    }
-   my $er=Wx::BitmapButton->new($rightbottom,-1,$eng,[30,$eht]);
-   $er->Enable(1);
+   my $cb=Wx::BitmapButton->new($rightbottom,-1,$clb,[30,$cbt]);
+   $cb->Enable(1);
+   my $gnu = Wx::Bitmap->new("gnusoc.png",
+                         wxBITMAP_TYPE_PNG );
+   my $gnt=135;
+   if ($pem_file && $ip_txt) {
+      $gnt=16;
+   }
+   my $gs=Wx::BitmapButton->new($rightbottom,-1,$gnu,[30,$gnt]);
+   $gs->Enable(1);
    $rightbottom->{bb}=$bb;
    $rightbottom->{bmp}=$bmp;
 
+
    my $gif='';
    if (-e "standup.gif") {
       $gif=Wx::Animation->new();
@@ -427,7 +442,8 @@ sub SplitterWindow {
    $rightbottom->{ip_txt} = $ip_txt if $ip_txt;
    $rightbottom->{tagged} = $tagged if defined $tagged;
    EVT_BUTTON( $rightbottom, $bb, \&fullauto_button);
-   EVT_BUTTON( $rightbottom, $er, \&enginerm_button);
+   EVT_BUTTON( $rightbottom, $cb, \&cb_button);
+   EVT_BUTTON( $rightbottom, $gs, \&gs_button);
    EVT_DROP_FILES( $rightbottom, \&main::on_drop );
 
    $rightbottom->Show(1);
@@ -698,6 +714,20 @@ print "GOING TO RUNPUTTY: runputty \"$self->{ppk_file}\" $iptext\n";
 
 }
 
+sub cb_button {
+
+   my ($self, $event) =@_;
+   Wx::PdfDocument::LaunchPdfViewer('');
+
+}
+
+sub gs_button {
+
+   my ($self, $event) =@_;
+   Wx::PdfDocument::LaunchPdfViewer('');
+
+}
+
 sub enginerm_button {
 
    my ($self, $event) =@_;
